pub enum Info {
ConnectionsMet,
SuccessfulHandshake,
Progress {
chain_height: u32,
filters_downloaded_percent: f32,
},
BlockReceived(String),
}Expand description
A log message from the node.
Variants
ConnectionsMet
All the required connections have been met. This is subject to change.
SuccessfulHandshake
The node was able to successfully connect to a remote peer.
Progress
A percentage value of filters that have been scanned.
Fields
BlockReceived(String)
A relevant block was downloaded from a peer.