pub enum Warning {
NeedConnections,
PeerTimedOut,
CouldNotConnect,
NoCompactFilters,
PotentialStaleTip,
UnsolicitedMessage,
TransactionRejected {
wtxid: String,
reason: Option<String>,
},
EvaluatingFork,
UnexpectedSyncError {
warning: String,
},
RequestFailed,
}Expand description
Warnings a node may issue while running.
Variants
NeedConnections
The node is looking for connections to peers.
PeerTimedOut
A connection to a peer timed out.
CouldNotConnect
The node was unable to connect to a peer in the database.
NoCompactFilters
A connection was maintained, but the peer does not signal for compact block filers.
PotentialStaleTip
The node has been waiting for new inv and will find new peers to avoid block withholding.
UnsolicitedMessage
A peer sent us a peer-to-peer message the node did not request.
TransactionRejected
A transaction got rejected, likely for being an insufficient fee or non-standard transaction.
EvaluatingFork
The peer sent us a potential fork.
UnexpectedSyncError
An unexpected error occurred processing a peer-to-peer message.
RequestFailed
The node failed to respond to a message sent from the client.