bdkffi::kyoto

Struct CbfClient

pub struct CbfClient { /* private fields */ }
A CbfClient handles wallet updates from a CbfNode.

Implementations

Source

impl CbfClient

pub async fn next_info(&self) -> Result<Info, CbfError>

Return the next available info message from a node. If none is returned, the node has stopped.

pub async fn next_warning(&self) -> Result<Warning, CbfError>

Return the next available warning message from a node. If none is returned, the node has stopped.

pub async fn update(&self) -> Result<Update, CbfError>

Return an Update. This is method returns once the node syncs to the rest of the network or a new block has been gossiped.

pub async fn broadcast( &self, transaction: &Transaction, ) -> Result<Arc<Wtxid>, CbfError>

Broadcast a transaction to the network, erroring if the node has stopped running.

pub async fn min_broadcast_feerate(&self) -> Result<Arc<FeeRate>, CbfError>

The minimum fee rate required to broadcast a transcation to all connected peers.

pub async fn average_fee_rate( &self, blockhash: Arc<BlockHash>, ) -> Result<Arc<FeeRate>, CbfError>

Fetch the average fee rate for a block by requesting it from a peer. Not recommend for resource-limited devices.

pub fn connect(&self, peer: Peer) -> Result<(), CbfError>

Add another Peer to attempt a connection with.

pub fn lookup_host(&self, hostname: String) -> Vec<Arc<IpAddress>>

Query a Bitcoin DNS seeder using the configured resolver.

This is not a generic DNS implementation. Host names are prefixed with a x849 to filter for compact block filter nodes from the seeder. For example dns.myseeder.com will be queried as x849.dns.myseeder.com. This has no guarantee to return any IpAddr.

pub fn is_running(&self) -> bool

Check if the node is still running in the background.

pub fn shutdown(&self) -> Result<(), CbfError>

Stop the CbfNode. Errors if the node is already stopped.