pub struct CbfComponents {
pub client: Arc<CbfClient>,
pub node: Arc<CbfNode>,
}Fields
client: Arc<CbfClient>Publish events to the node, like broadcasting transactions or adding scripts.
node: Arc<CbfNode>The node to run and fetch transactions for a Wallet.