pub struct Peer {
pub address: Arc<IpAddress>,
pub port: Option<u16>,
pub v2_transport: bool,
}Expand description
A peer to connect to over the Bitcoin peer-to-peer network.
Fields
address: Arc<IpAddress>The IP address to reach the node.
port: Option<u16>The port to reach the node. If none is provided, the default port for the selected network will be used.
v2_transport: boolDoes the remote node offer encrypted peer-to-peer connection.